@@ -1,8 +1,14 @@
 import xmltodict
-from dicttoxml import dicttoxml
 
 from .builder import Builder
 
+try:
+    from dicttoxml import dicttoxml
+except ImportError:
+    from .dicttoxml import DictToXML
+
+    dicttoxml = DictToXML().dicttoxml
+
 
 class XmlBuilder(Builder):
     def _build(self, data, **kwargs):
