@@ -53,19 +53,42 @@ class ResponseBuilder:
 
         self._builders.update({name: builder})
 
-        def _builder_attr(**kwargs):
+        def _builder_attr(**params):
             def _wrapper(func=None, data=None):
+                """
+                func and data are mutual exclusive:
+                    if func is present means a decorator builder used
+                    if data is provided means decorator used as attribute
+
+                :param func:
+                :param data:
+                :return:
+                """
                 if func is not None:
                     @wraps(func)
                     def wrapped():
-                        return self.build_response(name, func(), **kwargs)
+                        return self.build_response(name, func(), **params)
+
                     return wrapped
 
-                return self.build_response(name, data, **kwargs)
+                return self.build_response(name, data, **params)
+
             return _wrapper
 
         setattr(self, name, _builder_attr)
 
+    @staticmethod
+    def _empty_response(status, headers):
+        """
+
+        :param status:
+        :param headers:
+        :return:
+        """
+        resp = flask.make_response(b'', status, headers)
+        resp.headers.pop('Content-Type', None)
+        return resp
+
     def build_response(self, builder=None, data=None, **kwargs):
         """
 
@@ -78,6 +101,9 @@ class ResponseBuilder:
 
         data, status, headers = self.normalize_response_data(data)
 
+        if not data:
+            return self._empty_response(status, headers)
+
         if not builder:
             m = headers.get('Content-Type') or cap.config.get('RB_DEFAULT_RESPONSE_FORMAT')
             for value in self._builders.values():
@@ -104,6 +130,7 @@ class ResponseBuilder:
         :param strict:
         :return:
         """
+
         def find_builder(a):
             for b in self._builders.values():
                 if a == b.mimetype:
@@ -148,18 +175,19 @@ class ResponseBuilder:
         :param func:
         :return:
         """
+
         @wraps(func)
         def wrapped(*args, **kwargs):
             resp = func(*args, **kwargs)
             data, status, headers = self.normalize_response_data(resp)
 
-            if status is None or status == 204:
-                resp = flask.make_response('', 204, headers)
-                resp.headers.pop('Content-Type', None)
-                resp.headers.pop('Content-Length', None)
-                return resp
+            if data:
+                resp = self.build_response(data=resp)
+            else:
+                status = 204 if status in (None, 204) else status
+                resp = self._empty_response(status, headers)
 
-            return self.build_response(data=resp)
+            return resp
 
         return wrapped
 
@@ -170,6 +198,7 @@ class ResponseBuilder:
         :param acceptable:
         :return:
         """
+
         def response(fun):
             @wraps(fun)
             def wrapper(*args, **kwargs):
@@ -181,7 +210,9 @@ class ResponseBuilder:
                             break
 
                 return self.build_response(builder, fun(*args, **kwargs))
+
             return wrapper
+
         return response
 
     def on_accept(self, default=None, acceptable=None, strict=True):
@@ -192,12 +223,15 @@ class ResponseBuilder:
         :param strict:
         :return:
         """
+
         def response(fun):
             @wraps(fun)
             def wrapper(*args, **kwargs):
                 mimetype, builder = self.get_mimetype_accept(default, acceptable, strict)
                 return self.build_response(builder, fun(*args, **kwargs))
+
             return wrapper
+
         return response
 
     def response(self, builder, **kwargs):
@@ -206,11 +240,14 @@ class ResponseBuilder:
         :param builder:
         :return:
         """
+
         def _response(f):
             @wraps(f)
             def wrapper(*args, **kw):
                 return self.build_response(builder, f(*args, **kw), **kwargs)
+
             return wrapper
+
         return _response
 
     def template_or_json(self, template: str, as_table=False, to_dict=None):
@@ -221,6 +258,7 @@ class ResponseBuilder:
         :param to_dict:
         :return:
         """
+
         def response(fun):
             @wraps(fun)
             def wrapper(*args, **kwargs):
@@ -238,5 +276,7 @@ class ResponseBuilder:
 
                 resp = fun(*args, **kwargs)
                 return self.build_response(builder, resp, **varargs)
+
             return wrapper
+
         return response
